
Principle of least privilege
-------

**Description:**

The principle of least privilege recommends that accounts have the least amount of 
privilege required to perform their business processes. This encompasses user rights, 
resource permissions such as CPU limits, memory, network, and file system permissions. 


**Solution:**

The principle means giving a user account only those privileges which are essential to 
that users work. For example, a backup user does not need to install software: hence, 
the backup user has rights only to run backup and backup-related applications. 
Any other privileges, such as installing new software, are blocked. 

The principle applies also to a personal computer user who usually does work in a normal 
user account, and opens a privileged, password protected account (that is, a superuser) 
only when the situation absolutely demands it.

	